@@ -21,6 +21,7 @@ from keras import backend
 import matplotlib.pyplot as plt
 import numpy as np
 import h5py
+from pathlib import Path
 
 class ANNRegression():
     """Trains feedforward ANN using power system load flow load/voltage data"""
@@ -248,8 +249,8 @@ class ParametricRegression():
     def saveModel(self, model_name):
         """Encodes parametric model parameters into HDF5 binary data format"""
 
-        path = './data/function_mappings/'
-        with h5py.File(path + model_name + '.h5', 'w') as file:
+        path = Path.cwd() / 'data/function_mappings/'
+        with h5py.File(str(path / (model_name + '.h5')), 'w') as file:
             file.create_dataset(name='data', data=np.array(self.theta))
         file.close()
 
